.. _api_reference/models-extension:

Extension hookspec
============================

.. automodule:: sdgx.models.extension
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
   :private-members:
